From 44732939bca8ba767d6ce5ea45085cf421d76595 Mon Sep 17 00:00:00 2001
From: "Matthias P. Braendli" <matthias.braendli@mpb.li>
Date: Fri, 9 Mar 2018 15:30:15 +0100
Subject: Fix spelling of writting, remove old dabOutput.cpp

---
 src/dabOutput/dabOutput.cpp     | 109 ----------------------------------------
 src/dabOutput/dabOutputFifo.cpp |   4 +-
 src/dabOutput/dabOutputFile.cpp |   8 +--
 src/dabOutput/dabOutputRaw.cpp  |   8 +--
 4 files changed, 10 insertions(+), 119 deletions(-)
 delete mode 100644 src/dabOutput/dabOutput.cpp

(limited to 'src')

diff --git a/src/dabOutput/dabOutput.cpp b/src/dabOutput/dabOutput.cpp
deleted file mode 100644
index 7144e20..0000000
--- a/src/dabOutput/dabOutput.cpp
+++ /dev/null
@@ -1,109 +0,0 @@
-#include <cstdio>
-#include <cstring>
-#include <fcntl.h>
-#include <limits.h>
-#include "dabOutput.h"
-
-
-
-DabOutputFifo::open(const char* name)
-{
-    char* token = strchr((char*)filename, '?');
-    if (token != NULL) {
-        *(token++) = 0;
-        char* nextPair;
-        char* key;
-        char* value;
-        // Go through all the &stuff=foo pairs
-        // Only the key "type" is supported
-        do {
-            nextPair = strchr(token, '&');
-            if (nextPair != NULL) {
-                *nextPair = 0;
-            }
-            key = token;
-            value = strchr(token, '=');
-            if (value != NULL) {
-                *(value++) = 0;
-                if (strcmp(key, "type") == 0) {
-                    if (strcmp(value, "raw") == 0) {
-                        this->type_ = ETI_FILE_TYPE_RAW;
-                        break;
-                    } else if (strcmp(value, "framed") == 0) {
-                        this->type = ETI_FILE_TYPE_FRAMED;
-                        break;
-                    } else if (strcmp(value, "streamed") == 0) {
-                        this->type = ETI_FILE_TYPE_STREAMED;
-                        break;
-                    } else {
-                        etiLog.log(error,
-                                "File type '%s' is not supported.\n", value);
-                        return -1;
-                    }
-                }
-                else {
-                    etiLog.log(warn, "Parameter '%s' unknown\n", key);
-                }
-            }
-        } while (nextPair != NULL);
-    }
-
-    this->file_ = open(filename, O_WRONLY | O_CREAT | O_TRUNC | O_BINARY, 0666);
-    if (this->file_ == -1) {
-        perror(filename);
-        return -1;
-    }
-    return 0;
-}
-
-int DabOutputFifo::write(void* buffer, int size)
-{
-    uint8_t padding[6144];
-
-    switch (this->type_) {
-        case ETI_FILE_TYPE_FRAMED:
-            if (this->nbFrames_ == 0) {
-                uint32_t nbFrames = (uint32_t)-1;
-                // Writing nb frames
-                if (write(this->file_, &nbFrames, 4) == -1)
-                    goto FIFO_WRITE_ERROR;
-            }
-        case ETI_FILE_TYPE_STREAMED:
-            // Writting frame length
-            if (write(this->file_, &size, 2) == -1)
-                goto FIFO_WRITE_ERROR;
-            // Appending data
-            if (write(this->file_, buffer, size) == -1)
-                goto FIFO_WRITE_ERROR;
-            break;
-        case ETI_FILE_TYPE_RAW:
-            // Appending data
-            if (write(this->file_, buffer, size) == -1)
-                goto FIFO_WRITE_ERROR;
-            // Appending padding
-            memset(padding, 0x55, 6144 - size);
-            if (write(this->file_, padding, 6144 - size) == -1)
-                goto FIFO_WRITE_ERROR;
-            break;
-        default:
-            etiLog.log(error, "File type is not supported.\n");
-            return -1;
-    }
-
-    return size;
-
-FIFO_WRITE_ERROR:
-    perror("Error while writting to file");
-    return -1;
-}
-
-int DabOutputFifo::close()
-{
-    if (close(this->file_) == 0) {
-        this->file_ = -1;
-        return 0;
-    }
-    perror("Can't close file");
-    return -1;
-}
-
diff --git a/src/dabOutput/dabOutputRaw.cpp b/src/dabOutput/dabOutputRaw.cpp
index d7c191c..edc3cc6 100644
--- a/src/dabOutput/dabOutputRaw.cpp
+++ b/src/dabOutput/dabOutputRaw.cpp
@@ -396,7 +396,7 @@ int DabOutputRaw::Write(void* buffer, int size)
         buffer_[i] = revTable[buffer_[i]];
     }
 
-    // Writting data
+    // Writing data
 #ifdef _WIN32
     DWORD result;
     if(!DeviceIoControl(socket_, IoctlCodeTxFrame, buffer_.data(), 6144,
@@ -436,13 +436,13 @@ RAW_WRITE_ERROR:
         (LPTSTR)&errMsg,
         0,
         NULL) == 0) {
-            fprintf(stderr, "Error while writting to raw socket: %i", err);
+            fprintf(stderr, "Error while writing to raw socket: %i", err);
     } else {
-        fprintf(stderr, "Error while writting to raw socket: %s", errMsg);
+        fprintf(stderr, "Error while writing to raw socket: %s", errMsg);
         LocalFree(errMsg);
     }
 #else
-    perror("Error while writting to raw socket");
+    perror("Error while writing to raw socket");
 #endif
 
     return -1;
diff --git a/src/dabOutput/dabOutputFifo.cpp b/src/dabOutput/dabOutputFifo.cpp
index f466199..9135ff1 100644
--- a/src/dabOutput/dabOutputFifo.cpp
+++ b/src/dabOutput/dabOutputFifo.cpp
@@ -79,7 +79,7 @@ int DabOutputFifo::Write(void* buffer, int size)
                     goto FIFO_WRITE_ERROR;
             }
         case ETI_FILE_TYPE_STREAMED:
             // Writting frame length
             if (write(this->file_, &size, 2) == -1)
                 goto FIFO_WRITE_ERROR;
             // Appending data
@@ -104,6 +104,6 @@ int DabOutputFifo::Write(void* buffer, int size)
     return size;
 
 FIFO_WRITE_ERROR:
-    perror("Error while writting to file");
+    perror("Error while writing to fifo");
     return -1;
 }
@@ -79,7 +79,7 @@ int DabOutputFifo::Write(void* buffer, int size)
             }
         case ETI_FILE_TYPE_STREAMED:
-            // Writting frame length
+            // Writing frame length
             if (write(this->file_, &size, 2) == -1)
                 goto FIFO_WRITE_ERROR;
diff --git a/src/dabOutput/dabOutputFile.cpp b/src/dabOutput/dabOutputFile.cpp
index b8e9e70..d798daa 100644
--- a/src/dabOutput/dabOutputFile.cpp
+++ b/src/dabOutput/dabOutputFile.cpp
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
 
     switch (this->type_) {
     case ETI_FILE_TYPE_FRAMED:
         // Writting nb of frames at beginning of file
         if (lseek(this->file_, 0, SEEK_SET) == -1) goto FILE_WRITE_ERROR;
         if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
 
         // Writting nb frame length at end of file
         if (lseek(this->file_, 0, SEEK_END) == -1) goto FILE_WRITE_ERROR;
         if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
 
@@ -62,7 +62,7 @@ int DabOutputFile::Write(void* buffer, int size)
         if (write(this->file_, buffer, size) == -1) goto FILE_WRITE_ERROR;
         break;
     case ETI_FILE_TYPE_STREAMED:
         // Writting nb frame length at end of file
         if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
 
         // Appending data
@@ -85,7 +85,7 @@ int DabOutputFile::Write(void* buffer, int size)
     return size;
 
 FILE_WRITE_ERROR:
-    perror("Error while writting to file");
+    perror("Error while writing to file");
     return -1;
 }
 
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
     switch (this->type_) {
     case ETI_FILE_TYPE_FRAMED:
-        // Writting nb of frames at beginning of file
+        // Writing nb of frames at beginning of file
         if (lseek(this->file_, 0, SEEK_SET) == -1) goto FILE_WRITE_ERROR;
         if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
@@ -50,11 +50,11 @@ int DabOutputFile::Write(void* buffer, int size)
         if (write(this->file_, &this->nbFrames_, 4) == -1) goto FILE_WRITE_ERROR;
 
-        // Writting nb frame length at end of file
+        // Writing nb frame length at end of file
         if (lseek(this->file_, 0, SEEK_END) == -1) goto FILE_WRITE_ERROR;
         if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
@@ -62,7 +62,7 @@ int DabOutputFile::Write(void* buffer, int size)
         break;
     case ETI_FILE_TYPE_STREAMED:
-        // Writting nb frame length at end of file
+        // Writing nb frame length at end of file
         if (write(this->file_, &frame_size, 2) == -1) goto FILE_WRITE_ERROR;
 
-- 
cgit v1.2.3